%define pkg_desc It provides an interface from the Python scripting language to the ESO-MIDAS\
astronomical data processing system. It allows a user to exploit both the\
rich legacy of MIDAS software and the power of Python scripting in a unified\
interactive environment which also opens up other Python-based astronomical\
analysis systems such as PyRAF.

Name:           scisoft-python-pymidas
Version:        1.0.5
Release:        1%{?dist}
Summary:        Python routines and C extensions for MIDAS
Distribution:   Scisoft
License:        GPLv2+
Group:          Applications/Scientific
Packager:       Carlos Guirao <cguirao@eso.org>
URL:            http://www.eso.org/sci/software/sampo/pymidas/
Source0:        http://www.eso.org/sci/software/sampo/pymidas/pymidas-%{version}.tar.gz
Source1:        http://www.eso.org/sci/software/sampo/pymidas/PyMidas_SW_User_Manual.pdf
Patch0:         Sergio.Gelato.patch

BuildRequires: perl
BuildRequires: gcc-c++
BuildRequires: scisoft-midas
BuildRequires: python2-devel
BuildRequires: ncurses-devel
BuildRequires: readline-devel

%define midas_path /scisoft/share/midas

%description
%{pkg_desc}


%package -n scisoft-python2-pymidas
Summary:    %{summary}
Provides:   scisoft-python-pymidas

%description -n scisoft-python2-pymidas
%{pkg_desc}


%prep
%setup -q -n pymidas-%{version}

#  Sergio Gelato reported two bugs in Pymidas and provided a patch to fix
#  them, it might be worth checking in the future if these patches have
#  been implemented upstream:
#  "I have found two bugs in the most recent published version of PyMidas,
#    version 1.0.5. I know that ESO does not officially support PyMidas, but
#    since http://www.eso.org/sci/software/sampo/pymidas/ says that "[f]eedback
#    and bug reports should be sent to pymidas(AT)eso.org" I'm now doing that."
#  Patch description:
#  * iCid is an int; telling PyArg_ParseTuple to treat it as a double
#    causes memory corruption, so don't do that.
#  * gpResponseBuf is created with new[], must be deallocated with delete[].
#    (gpResponseBuf is allocated in init_pymidas_c_00() using new[]. The code paths
#    that assign to gpResponseBuf other values that were not allocated with new[]
#    seem to be effectively dead; they should be expunged, but this will be left
#    for another patch.)
#patch -p0 < $SCISOFT_SRC/pymidas/Sergio.Gelato.patch
%patch0 -p0

%build
MIDASVER=`ls %{midas_path}/`
{
  # continue (y/n)?
  echo y
} | %py2_build -- --midashome=%{midas_path} --midvers=$MIDASVER

%install
MIDASVER=`ls %{midas_path}/`
{
  # continue (y/n)?
  echo y
} | %py2_install -- --midashome=%{midas_path} --midvers=$MIDASVER
perl -pi -e 's/python -i/python/' %{buildroot}%{_bindir}/pymidas
install -m 755 -d %{buildroot}%{_docdir}/pymidas
install -m 644 %{SOURCE1} %{buildroot}%{_docdir}/pymidas/

%files -n scisoft-python2-pymidas
%{_docdir}/pymidas
%docdir %{_docdir}/pymidas
%{_bindir}/*
%{python2_sitearch}/*


%changelog
* Mon Mar 19 2018 Artur Szostak <aszostak@partner.eso.org> 1.0.5
- Integrated PyMidas into automated build system.
- Updated to use standard RPM macros for building and installation of python
  packages.

* Fri May 5 2017 Artur Szostak <aszostak@partner.eso.org> 1.0.5-6
- Updating MIDAS dependency to version 17FEBpl.

* Mon Oct 24 2016 Artur Szostak <aszostak@partner.eso.org> 1.0.5-5
- Adding missing build dependencies for MIDAS.

* Thu Nov 14 2013 <cguirao@eso.org>
- adapted to SCISOFT 
